/**
 * @file
 * Adds Lazy loading to inline frame elements on the site.
 *
 * Check for native browser support of
 * https://developer.mozilla.org/en-US/docs/Web/HTML/Element/iframe#attr-loading
 * Fall back to https://github.com/aFarkas/lazysizes if not.
 */

if ('loading' in HTMLIFrameElement.prototype) {
  const iframes = document.querySelectorAll('iframe[loading="lazy"]');
  iframes.forEach(iframe => {
    iframe.src = iframe.dataset.src;
  });
}
else {
  const script = document.createElement('script');
  script.src = 'https://cdnjs.cloudflare.com/ajax/libs/lazysizes/5.1.2/lazysizes.min.js';
  script.setAttribute('async', '');
  document.body.appendChild(script);
}
