<?php

declare(strict_types = 1);

namespace Drupal\media_iframe\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * A iframe formatter for URI fields.
 *
 * @FieldFormatter(
 *   id = "inline_frame",
 *   label = @Translation("iFrame"),
 *   field_types = {
 *     "uri",
 *   },
 * )
 */
class InlineFrameFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function getMediaType() {
    return 'inline_frame';
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $entity = $items->getEntity();
    $element = [];
    foreach ($items as $delta => $item) {
      $element[$delta] = [
        '#type' => 'html_tag',
        '#tag' => 'iframe',
        '#attributes' => [
          'title' => $entity->label(),
          'data-src' => $item->value,
          'frameborder' => 0,
          'scrolling' => FALSE,
          'allowtransparency' => TRUE,
          'class' => ['lazyload'],
          'loading' => 'lazy',
          'width' => '100%',
        ],
        '#attached' => [
          'library' => 'media_iframe/lazy_iframe',
        ],
      ];
    }
    return $element;
  }

}
