<?php

declare(strict_types = 1);

namespace Drupal\media_iframe\Plugin\media\Source;

use Drupal\Core\Entity\Display\EntityViewDisplayInterface;
use Drupal\field\FieldConfigInterface;
use Drupal\media\MediaSourceBase;
use Drupal\media\MediaTypeInterface;

/**
 * Iframe entity media source.
 *
 * @MediaSource(
 *   id = "inline_frame",
 *   label = @Translation("Inline frame"),
 *   allowed_field_types = {"uri"},
 *   default_thumbnail_filename = "iframe.png",
 *   description = @Translation("Provides inline frame media type.")
 * )
 */
class InlineFrame extends MediaSourceBase {

  /**
   * {@inheritdoc}
   */
  public function getMetadataAttributes(): array {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function createSourceField(MediaTypeInterface $type): FieldConfigInterface {
    return parent::createSourceField($type)->set('label', 'Inline Frame URL');
  }

  /**
   * {@inheritdoc}
   */
  public function prepareViewDisplay(MediaTypeInterface $type, EntityViewDisplayInterface $display) {
    $display->setComponent($this->getSourceFieldDefinition($type)->getName(), [
      'type' => 'inline_frame',
      'label' => 'visually_hidden',
    ]);
  }

}
